@@ -1,12 +1,11 @@
 import os
 import random
-from abc import ABC
 from collections import Counter, deque
 from contextlib import suppress
 from dataclasses import is_dataclass
 from datetime import date, datetime, time, timedelta
 from decimal import Decimal
-from enum import EnumMeta
+from enum import Enum, EnumMeta
 from inspect import isclass
 from ipaddress import (
     IPv4Address,
@@ -21,7 +20,6 @@ from typing import (
     TYPE_CHECKING,
     Any,
     Callable,
-    ClassVar,
     Dict,
     Generic,
     ItemsView,
@@ -83,10 +81,12 @@ from pydantic import (
     StrictFloat,
     StrictInt,
     StrictStr,
+    create_model_from_typeddict,
 )
 from pydantic.color import Color
-from pydantic.fields import SHAPE_MAPPING
-from typing_extensions import TypeGuard, get_args
+from pydantic.fields import SHAPE_DICT, SHAPE_MAPPING
+from typing_extensions import _TypedDictMeta  # type: ignore
+from typing_extensions import TypeGuard, get_args, is_typeddict
 
 from pydantic_factories.constraints.collection import handle_constrained_collection
 from pydantic_factories.constraints.date import handle_constrained_date
@@ -113,6 +113,7 @@ from pydantic_factories.utils import (
     is_literal,
     is_optional,
     is_pydantic_model,
+    unwrap_new_type_if_needed,
 )
 from pydantic_factories.value_generators.complex_types import handle_complex_type
 from pydantic_factories.value_generators.primitives import (
@@ -123,149 +124,239 @@ from pydantic_factories.value_generators.primitives import (
 if TYPE_CHECKING:
     from pydantic.fields import ModelField
 
-T = TypeVar("T", bound=Union[BaseModel, DataclassProtocol])
+try:
+    from typing import _TypedDictMeta as TypingTypedDictMeta  # type: ignore
+except ImportError:
+    TypingTypedDictMeta = _TypedDictMeta
 
-default_faker = Faker()
+FactoryTypes = Union[BaseModel, DataclassProtocol, TypingTypedDictMeta, _TypedDictMeta]
+
+T = TypeVar("T", bound=FactoryTypes)
 
 
-class ModelFactory(ABC, Generic[T]):  # noqa: B024
-    __model__: ClassVar[Type[T]]  # type: ignore[misc]
-    __faker__: ClassVar[Optional[Faker]]
-    __sync_persistence__: ClassVar[  # type: ignore[misc]
-        Optional[Union[Type[SyncPersistenceProtocol[T]], SyncPersistenceProtocol[T]]]
-    ] = None
-    __async_persistence__: ClassVar[  # type: ignore[misc]
-        Optional[Union[Type[AsyncPersistenceProtocol[T]], AsyncPersistenceProtocol[T]]]
-    ] = None
-    __allow_none_optionals__: ClassVar[bool] = True
-    __random_seed__: ClassVar[Optional[int]] = None
+class ModelFactory(Generic[T]):
+    __model__: Type[T]
+    __faker__: Faker = Faker()
+    __sync_persistence__: Optional[Union[Type[SyncPersistenceProtocol[T]], SyncPersistenceProtocol[T]]] = None
+    __async_persistence__: Optional[Union[Type[AsyncPersistenceProtocol[T]], AsyncPersistenceProtocol[T]]] = None
+    __allow_none_optionals__: bool = True
+    __random_seed__: Optional[int] = None
+    __auto_register__: bool = False
+
+    # Private Fields
+    _registered_model_factory_map: Dict[FactoryTypes, "ModelFactory[T]"] = {}
 
     # Private Methods
 
+    def __init_subclass__(cls, *args: Any, **kwargs: Any) -> None:
+        super().__init_subclass__(*args, **kwargs)
+        if cls.__auto_register__:
+            cls._register_model_factory()
+
     @classmethod
     def _get_model(cls) -> Type[T]:
         """Returns the factory's model."""
         if not hasattr(cls, "__model__") or not cls.__model__:
             raise ConfigurationError("missing model class in factory Meta")
-        model = cls.__model__
-        if is_pydantic_model(model):
+
+        if is_pydantic_model(cls.__model__):
             with suppress(NameError):
-                cast("BaseModel", model).update_forward_refs()
-        return model
+                cls.__model__.update_forward_refs()
+
+        return cast("Type[T]", cls.__model__)
 
     @classmethod
     def _get_sync_persistence(cls) -> SyncPersistenceProtocol[T]:
         """Returns a sync_persistence interface if present."""
-        persistence = cls.__sync_persistence__
-        if persistence:
-            return persistence if not callable(persistence) else persistence()  # pylint: disable=not-callable
+        if cls.__sync_persistence__:
+            if callable(cls.__sync_persistence__):
+                return cls.__sync_persistence__()
+            return cls.__sync_persistence__
         raise ConfigurationError("A sync_persistence handler must be defined in the factory to use this method")
 
     @classmethod
     def _get_async_persistence(cls) -> AsyncPersistenceProtocol[T]:
         """Returns an async_persistence interface."""
-        persistence = cls.__async_persistence__
-        if persistence:
-            return persistence if not callable(persistence) else persistence()  # pylint: disable=not-callable
+        if cls.__async_persistence__:
+            if callable(cls.__async_persistence__):
+                return cls.__async_persistence__()
+            return cls.__async_persistence__
         raise ConfigurationError("An async_persistence handler must be defined in the factory to use this method")
 
     @classmethod
-    def _is_kwargs_missing_pydantic_fields(cls, pydantic_model: Type[T], pydantic_model_kwargs: Any) -> bool:
-        """Determines if the kwargs are missing fields that should be defined
-        in the pydantic model.
+    def _are_model_kwargs_partial(cls, pydantic_model: Type[BaseModel], model_kwargs: Any) -> bool:
+        """Determines if the kwargs are missing fields that should be defined in the pydantic model.
 
         Returns False if all fields of the pydantic model are defined in
         the kwargs, and True otherwise.
+
+        Args:
+            pydantic_model: A pydantic model class.
+            model_kwargs: Any kwargs.
+
+        Returns:
+            A boolean determining if kwargs are missing.
         """
-        if is_pydantic_model(pydantic_model_kwargs.__class__) or pydantic_model_kwargs is None:
+        if not model_kwargs or is_pydantic_model(type(model_kwargs)):
             return False
-        pydantic_model_fields = cls.get_model_fields(pydantic_model)
-        pydantic_model_field_names = {field_name for field_name, _ in pydantic_model_fields}
-        kwargs_field_names = set(pydantic_model_kwargs.keys())
+
+        if isinstance(model_kwargs, list):
+            return any(
+                cls._are_model_kwargs_partial(pydantic_model, pydantic_model_kwargs)
+                for pydantic_model_kwargs in model_kwargs
+            )
+
+        pydantic_model_field_names = set()
+        for field_name, model_field in cls.get_model_fields(cast("Type[T]", pydantic_model)):
+            field_kwargs = model_kwargs.get(field_name)
+            if is_pydantic_model(model_field.type_) and cls._are_model_kwargs_partial(model_field.type_, field_kwargs):
+                return True
+
+            pydantic_model_field_names.add(field_name)
+
+        kwargs_field_names = set(model_kwargs.keys())
+
         return bool(pydantic_model_field_names - kwargs_field_names)
 
     @classmethod
-    def _is_pydantic_with_partial_fields(cls, field_name: str, model_field: "ModelField", **kwargs: Any) -> bool:
-        """Determines if the field is a pydantic model AND if the kwargs are
-        missing fields that should be defined in the pydantic model.
+    def _is_pydantic_model_with_partial_fields(cls, field_name: str, model_field: "ModelField", **kwargs: Any) -> bool:
+        """Determines if the field is a pydantic model AND if the kwargs are missing fields that should be defined in
+        the pydantic model.
 
         Returns False if model_field isn't a Pydantic model OR if all
         fields of the pydantic model are defined in the kwargs, and True
         otherwise.
+
+        Args:
+            field_name: Field name.
+            model_field: A 'ModelField' instance.
+            **kwargs: Any kwargs.
+
+        Returns:
+            A boolean determining whether the given field value is a pydantic model with missing kwargs.
         """
-        pydantic_model = model_field.type_
-        if not is_pydantic_model(pydantic_model) or model_field.shape == SHAPE_MAPPING:
-            return False
+        if model_field.shape not in (SHAPE_DICT, SHAPE_MAPPING) and is_pydantic_model(model_field.type_):
+            field_kwargs = kwargs.get(field_name)
 
-        list_of_pydantic_models_kwargs = kwargs.get(field_name)
-        if not isinstance(list_of_pydantic_models_kwargs, list):
-            return cls._is_kwargs_missing_pydantic_fields(pydantic_model, list_of_pydantic_models_kwargs)
+            return cls._are_model_kwargs_partial(model_field.type_, field_kwargs)
 
-        return any(
-            cls._is_kwargs_missing_pydantic_fields(pydantic_model, pydantic_model_kwargs)
-            for pydantic_model_kwargs in list_of_pydantic_models_kwargs
-        )
+        return False
 
     @classmethod
     def _should_use_alias_name(cls, model_field: "ModelField", model: Type[T]) -> bool:
-        """Determines whether a given model field should be set by an alias."""
-        if not model_field.alias:
-            return False
+        """Determines whether a given model field should be set by an alias.
 
-        if issubclass(model, BaseModel) and model.__config__.allow_population_by_field_name:
-            return False
-        return True
+        Args:
+            model_field: A 'ModelField' instance.
+            model: A model class.
+
+        Returns:
+            A boolean determining whether the field alias should be used.
+        """
+        return bool(model_field.alias) and not (
+            issubclass(model, BaseModel) and model.__config__.allow_population_by_field_name
+        )
 
     @classmethod
-    def _handle_constrained_field(cls, model_field: "ModelField") -> Any:
-        """Handle the built-in pydantic constrained value field types."""
-        outer_type = model_field.outer_type_
-        try:
-            if issubclass(outer_type, ConstrainedFloat):
-                return handle_constrained_float(field=cast("ConstrainedFloat", outer_type))
-            if issubclass(outer_type, ConstrainedInt):
-                return handle_constrained_int(field=cast("ConstrainedInt", outer_type))
-            if issubclass(outer_type, ConstrainedDecimal):
-                return handle_constrained_decimal(field=cast("ConstrainedDecimal", outer_type))
-            if issubclass(outer_type, ConstrainedStr):
-                return handle_constrained_string(
-                    field=cast("ConstrainedStr", outer_type), random_seed=cls.__random_seed__
-                )
-            if issubclass(outer_type, ConstrainedBytes):
-                return handle_constrained_bytes(field=cast("ConstrainedBytes", outer_type))
-            if issubclass(outer_type, (ConstrainedSet, ConstrainedList, ConstrainedFrozenSet)):
-                collection_type = list if issubclass(outer_type, ConstrainedList) else set
-                result = handle_constrained_collection(
-                    collection_type=collection_type, model_field=model_field, model_factory=cls  # type: ignore
-                )
-                if issubclass(outer_type, ConstrainedFrozenSet):  # pragma: no cover
-                    return frozenset(*result)
-                return result
-            if issubclass(outer_type, ConstrainedDate):
-                return handle_constrained_date(constrained_date=outer_type, faker=cls.get_faker())
-            raise ParameterError(f"Unknown constrained field: {outer_type.__name__}")  # pragma: no cover
-        except AssertionError as e:  # pragma: no cover
-            raise ParameterError from e
+    def _handle_constrained_field(
+        cls, model_field: "ModelField"
+    ) -> Union[float, int, Decimal, date, str, bytes, set, frozenset, list]:
+        """Handle the built-in pydantic constrained value field types.
+
+        Args:
+            model_field: A 'ModelField' instance for a pydantic ConstrainedField type.
+
+        Returns:
+            An appropriate value for the given field type.
+        """
+        outer_type = unwrap_new_type_if_needed(model_field.outer_type_)
+        if issubclass(outer_type, ConstrainedFloat):
+            return handle_constrained_float(field=cast("ConstrainedFloat", outer_type))
+
+        if issubclass(outer_type, ConstrainedInt):
+            return handle_constrained_int(field=cast("ConstrainedInt", outer_type))
+
+        if issubclass(outer_type, ConstrainedDecimal):
+            return handle_constrained_decimal(field=cast("ConstrainedDecimal", outer_type))
+
+        if issubclass(outer_type, ConstrainedStr):
+            return handle_constrained_string(field=cast("ConstrainedStr", outer_type), random_seed=cls.__random_seed__)
+
+        if issubclass(outer_type, ConstrainedBytes):
+            return handle_constrained_bytes(field=cast("ConstrainedBytes", outer_type))
+
+        if issubclass(outer_type, (ConstrainedSet, ConstrainedList, ConstrainedFrozenSet)):
+            collection_type = list if issubclass(outer_type, ConstrainedList) else set
+            result = handle_constrained_collection(
+                collection_type=collection_type, model_field=model_field, model_factory=cls  # type: ignore
+            )
+            return frozenset(result) if issubclass(outer_type, ConstrainedFrozenSet) else result
+
+        if issubclass(outer_type, ConstrainedDate):
+            return handle_constrained_date(constrained_date=outer_type, faker=cls.get_faker())
+
+        raise ParameterError(f"Unknown constrained field: {outer_type.__name__}")  # pragma: no cover
 
     @classmethod
-    def _handle_enum(cls, outer_type: EnumMeta) -> Any:
-        """Method that converts an enum to a list and picks a random element
-        out of it."""
+    def _handle_enum(cls, outer_type: Type[Enum]) -> Any:
+        """Method that converts an enum to a list and picks a random element out of it.
+
+        Args:
+            outer_type: An Enum class.
+
+        Returns:
+            A random member value.
+        """
         return random.choice(list(outer_type))
 
     @classmethod
     def _handle_factory_field(cls, field_value: Any) -> Any:
-        """Handles a field defined on the factory class itself."""
-        from pydantic_factories.fields import Use
+        """Handles a field defined on the factory class itself.
 
-        if isinstance(field_value, Use):
+        Args:
+            field_value: A value defined as an attribute on the factory class.
+
+        Returns:
+            An arbitrary value correlating with the given field value.
+        """
+        from pydantic_factories.fields import Fixture, Use
+
+        if isinstance(field_value, (Use, Fixture)):
             return field_value.to_value()
+
         if cls.is_model_factory(field_value):
             return cast("ModelFactory", field_value).build()
+
         if callable(field_value):
             return field_value()
+
         return field_value
 
+    @classmethod
+    def _get_or_create_factory(
+        cls,
+        model: Type[FactoryTypes],
+    ) -> "ModelFactory":
+        """get from registered factories or generate dynamically a 'ModelFactory' for a given pydantic model subclass.
+
+        Args:
+            model: A pydantic model subclass.
+        Returns:
+            A 'ModelFactory' subclass.
+        """
+        factory = cls._get_registered_model_factory(model)
+        if factory:
+            return factory
+        return cls.create_factory(model)
+
+    @classmethod
+    def _register_model_factory(cls) -> None:
+        cls._registered_model_factory_map[cls._get_model()] = cast("ModelFactory", cls)
+
+    @classmethod
+    def _get_registered_model_factory(cls, model: FactoryTypes) -> Optional["ModelFactory"]:
+        return cls._registered_model_factory_map.get(model)
+
     # Public Methods
 
     @classmethod
@@ -310,8 +401,7 @@ class ModelFactory(ABC, Generic[T]):  # noqa: B024
             Type[ConstrainedStr],
         ]
     ]:
-        """Method to determine if a given value is a pydantic Constrained
-        Field.
+        """Method to determine if a given value is a pydantic Constrained Field.
 
         Args:
             value: An arbitrary value.
@@ -356,9 +446,7 @@ class ModelFactory(ABC, Generic[T]):  # noqa: B024
         Returns:
             An instance of 'Faker'
         """
-        if hasattr(cls, "__faker__") and cls.__faker__:
-            return cls.__faker__
-        return default_faker
+        return cls.__faker__
 
     @classmethod
     def get_provider_map(cls) -> Dict[Any, Callable]:
@@ -480,12 +568,11 @@ class ModelFactory(ABC, Generic[T]):  # noqa: B024
     @classmethod
     def create_factory(
         cls,
-        model: Type[BaseModel],
+        model: Type[FactoryTypes],
         base: Optional[Type["ModelFactory"]] = None,
         **kwargs: Any,
     ) -> "ModelFactory":
-        """Dynamically generates a 'ModelFactory' for a given pydantic model
-        subclass.
+        """Dynamically generates a 'ModelFactory' for a given pydantic model subclass.
 
         Args:
             model: A pydantic model subclass.
@@ -505,7 +592,7 @@ class ModelFactory(ABC, Generic[T]):  # noqa: B024
             "ModelFactory",
             type(
                 f"{model.__name__}Factory",
-                (base or cls,),
+                (base or cls,),  # pyright: ignore
                 {"__model__": model, **kwargs},
             ),
         )
@@ -514,8 +601,7 @@ class ModelFactory(ABC, Generic[T]):  # noqa: B024
     def get_field_value(
         cls, model_field: "ModelField", field_parameters: Optional[Union[Dict[Any, Any], List[Any]]] = None
     ) -> Any:
-        """Returns a field value on the subclass if existing, otherwise returns
-        a mock value.
+        """Returns a field value on the subclass if existing, otherwise returns a mock value.
 
         Args:
             model_field: A pydantic 'ModelField'.
@@ -526,29 +612,40 @@ class ModelFactory(ABC, Generic[T]):  # noqa: B024
         """
         if model_field.field_info.const:
             return model_field.get_default()
+
         if cls.should_set_none_value(model_field=model_field):
             return None
-        outer_type = model_field.outer_type_
+
+        outer_type = unwrap_new_type_if_needed(model_field.outer_type_)
         if isinstance(outer_type, EnumMeta):
-            return cls._handle_enum(outer_type)
-        if is_pydantic_model(outer_type) or is_dataclass(outer_type):
-            build_kwargs: dict = field_parameters or {}  # type: ignore
-            return cls.create_factory(model=outer_type).build(**build_kwargs)
+            return cls._handle_enum(cast("Type[Enum]", outer_type))
+
+        if is_pydantic_model(outer_type) or is_dataclass(outer_type) or is_typeddict(outer_type):
+            return cls._get_or_create_factory(model=outer_type).build(
+                **(field_parameters if isinstance(field_parameters, dict) else {})
+            )
+
         if isinstance(field_parameters, list) and is_pydantic_model(model_field.type_):
             return [
-                cls.create_factory(model=model_field.type_).build(**build_kwargs) for build_kwargs in field_parameters
+                cls._get_or_create_factory(model=model_field.type_).build(**build_kwargs)
+                for build_kwargs in field_parameters
             ]
+
         if cls.is_constrained_field(outer_type):
             return cls._handle_constrained_field(model_field=model_field)
+
         if model_field.sub_fields:
             return handle_complex_type(model_field=model_field, model_factory=cls, field_parameters=field_parameters)
+
         if is_literal(model_field):
             literal_args = get_args(outer_type)
             return random.choice(literal_args)
+
         # this is a workaround for the following issue: https://github.com/samuelcolvin/pydantic/issues/3415
-        field_type = model_field.type_ if model_field.type_ is not Any else outer_type
+        field_type = unwrap_new_type_if_needed(model_field.type_) if model_field.type_ is not Any else outer_type
         if cls.is_ignored_type(field_type):
             return None
+
         return cls.get_mock_value(field_type=field_type)
 
     @classmethod
@@ -564,9 +661,7 @@ class ModelFactory(ABC, Generic[T]):  # noqa: B024
         Returns:
             A boolean determining whether 'None' should be set for the given field.
         """
-        if cls.__allow_none_optionals__:
-            return is_optional(model_field=model_field) and not create_random_boolean()
-        return False
+        return cls.__allow_none_optionals__ and (is_optional(model_field=model_field) and not create_random_boolean())
 
     @classmethod
     def should_set_field_value(cls, field_name: str, model_field: "ModelField", **kwargs: Dict[str, Any]) -> bool:
@@ -583,15 +678,15 @@ class ModelFactory(ABC, Generic[T]):  # noqa: B024
         Returns:
             A boolean determining whether a value should be set for the given field.
         """
-        is_field_ignored = False
-        is_field_in_kwargs = field_name in kwargs
-        is_partial_pydantic_model = cls._is_pydantic_with_partial_fields(field_name, model_field, **kwargs)
-        if hasattr(cls, field_name):
-            value = getattr(cls, field_name)
-            if isinstance(value, Require) and not is_field_in_kwargs:
-                raise MissingBuildKwargError(f"Require kwarg {field_name} is missing")
-            is_field_ignored = isinstance(value, Ignore)
-        return not is_field_ignored and (not is_field_in_kwargs or is_partial_pydantic_model)
+        value = getattr(cls, field_name, None)
+
+        if isinstance(value, Ignore):
+            return False
+
+        if isinstance(value, Require) and field_name not in kwargs:
+            raise MissingBuildKwargError(f"Require kwarg {field_name} is missing")
+
+        return field_name not in kwargs or cls._is_pydantic_model_with_partial_fields(field_name, model_field, **kwargs)
 
     @classmethod
     def get_model_fields(cls, model: Type[T]) -> ItemsView[str, "ModelField"]:
@@ -601,7 +696,7 @@ class ModelFactory(ABC, Generic[T]):  # noqa: B024
         model first.
 
         Args:
-            model: An arbitrary type T.
+            model: A model class of type T.
 
         Notes:
             - This method is distinct to allow overriding.
@@ -609,17 +704,24 @@ class ModelFactory(ABC, Generic[T]):  # noqa: B024
         Returns:
             An 'ItemsView' composed of field names and pydantic 'ModelField' instances.
         """
-        if not is_pydantic_model(model):
-            model = create_model_from_dataclass(dataclass=model)  # type: ignore
-        return model.__fields__.items()  # type: ignore
+        if is_pydantic_model(model):
+            return model.__fields__.items()
+
+        if is_dataclass(model):
+            return create_model_from_dataclass(dataclass=cast("Type[DataclassProtocol]", model)).__fields__.items()
+
+        if is_typeddict(model):
+            return create_model_from_typeddict(cast("Any", model)).__fields__.items()
+
+        raise ConfigurationError("unknown model type passed to 'get_model_fields'")
 
     @classmethod
     def build(cls, factory_use_construct: bool = False, **kwargs: Any) -> T:
         """builds an instance of the factory's __model__
 
         Args:
-            factory_use_construct: A boolea that determines whether validations will be made when instantiating the
-                model. this is supported only for pydantic models.
+            factory_use_construct: A boolean that determines whether validations will be made when instantiating the
+                model. This is supported only for pydantic models.
             **kwargs: Any kwargs. If field names are set in kwargs, their values will be used.
 
         Returns:
@@ -633,8 +735,9 @@ class ModelFactory(ABC, Generic[T]):  # noqa: B024
         for field_name, model_field in cls.get_model_fields(model):
             if cls._should_use_alias_name(model_field, model):
                 field_name = model_field.alias
+
             if cls.should_set_field_value(field_name, model_field, **kwargs):
-                if hasattr(cls, field_name):
+                if field_name not in dir(ModelFactory) and hasattr(cls, field_name):
                     value = getattr(cls, field_name)
                     if isinstance(value, PostGenerated):
                         generate_post[field_name] = value
@@ -642,13 +745,16 @@ class ModelFactory(ABC, Generic[T]):  # noqa: B024
                         kwargs[field_name] = cls._handle_factory_field(field_value=value)
                 else:
                     kwargs[field_name] = cls.get_field_value(model_field, field_parameters=kwargs.get(field_name, {}))
+
         for field_name, post_generator in generate_post.items():
             kwargs[field_name] = post_generator.to_value(field_name, kwargs)
+
         if factory_use_construct:
             if is_pydantic_model(cls.__model__):
-                return cls.__model__.construct(**kwargs)  # type: ignore
+                return cast("T", cls.__model__.construct(**kwargs))
             raise ConfigurationError("factory_use_construct requires a pydantic model as the factory's __model__")
-        return cast("T", cls.__model__(**kwargs))
+
+        return cast("T", cls.__model__(**kwargs))  # pyright: ignore
 
     @classmethod
     def batch(cls, size: int, **kwargs: Any) -> List[T]:
@@ -673,9 +779,7 @@ class ModelFactory(ABC, Generic[T]):  # noqa: B024
         Returns:
             An instance of type T.
         """
-        sync_persistence_handler = cls._get_sync_persistence()
-        instance = cls.build(**kwargs)
-        return sync_persistence_handler.save(data=instance)
+        return cls._get_sync_persistence().save(data=cls.build(**kwargs))
 
     @classmethod
     def create_batch_sync(cls, size: int, **kwargs: Any) -> List[T]:
@@ -688,9 +792,7 @@ class ModelFactory(ABC, Generic[T]):  # noqa: B024
         Returns:
             A list of instances of type T.
         """
-        sync_persistence_handler = cls._get_sync_persistence()
-        batch = cls.batch(size, **kwargs)
-        return sync_persistence_handler.save_many(data=batch)
+        return cls._get_sync_persistence().save_many(data=cls.batch(size, **kwargs))
 
     @classmethod
     async def create_async(cls, **kwargs: Any) -> T:
@@ -702,14 +804,11 @@ class ModelFactory(ABC, Generic[T]):  # noqa: B024
         Returns:
             An instance of type T.
         """
-        async_persistence_handler = cls._get_async_persistence()
-        instance = cls.build(**kwargs)
-        return await async_persistence_handler.save(data=instance)
+        return await cls._get_async_persistence().save(data=cls.build(**kwargs))
 
     @classmethod
     async def create_batch_async(cls, size: int, **kwargs: Any) -> List[T]:
-        """Builds and persists asynchronously a batch of n size model
-        instances.
+        """Builds and persists asynchronously a batch of n size model instances.
 
         Args:
             size: Size of the batch.
@@ -718,6 +817,4 @@ class ModelFactory(ABC, Generic[T]):  # noqa: B024
         Returns:
             A list of instances of type T.
         """
-        async_persistence_handler = cls._get_async_persistence()
-        batch = cls.batch(size, **kwargs)
-        return await async_persistence_handler.save_many(data=batch)
+        return await cls._get_async_persistence().save_many(data=cls.batch(size, **kwargs))
